from django.http import HttpResponseBadRequest

from graphite.util import htmlEscape, is_unsafe_str


class NormalizeEmptyResultError(Exception):
  # throw error for normalize() when empty
  pass


class InputParameterError(ValueError):
    pass


def safe_param(name, s):
    if is_unsafe_str(s):
        raise InputParameterError("{} contain unsafe symbols".format(name))
    return s


def is_unclean_str(s):
    for symbol in '&<>~!@#$%^*()`':
        if s.find(symbol) >= 0:
            return True
    return False


def str_param(name, s):
    if s is not None and is_unclean_str(s):
        raise InputParameterError("{} contain restricted symbols".format(name))
    return s


# decorator which turns InputParameterExceptions into Django's HttpResponseBadRequest
def handleInputParameterError(f):
    def new_f(*args, **kwargs):
        try:
            return f(*args, **kwargs)
        except InputParameterError as e:
            return HttpResponseBadRequest(htmlEscape(str(e)))

    return new_f
